# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-07-01 14:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('thorson_wiki', '0002_auto_20170106_0131'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='namespace',
            field=models.CharField(choices=[('rivenrock', 'The Rivenrock Wiki'), ('mosaic', 'Mosaic')], help_text="The article's namespace.", max_length=255, verbose_name='namespace'),
        ),
    ]
